@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.27 2004/01/14 11:39:31 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp,v 1.28 2004/02/11 11:53:32 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -266,6 +266,9 @@ impl_save (EphyEmbedPersist *persist)
 		if (NS_FAILED (rv)) return FALSE;
 	}
 
+	g_free (uri);
+	g_free (filename);
+
 	return TRUE;
 }
 
